@@ -361,6 +361,7 @@ static gboolean datasource_open_sndfile(Datasource *ds)
      int fd;
      fd = xopen(ds->data.sndfile.filename,O_RDONLY,0);
      if (fd == -1) return TRUE;
+     i.format = 0;
      s = sf_open_fd(fd,SFM_READ,&i,TRUE);
      if (s == NULL) {	  
 	  d = g_strdup_printf(_("Couldn't open %s"),
@@ -643,7 +644,8 @@ static guint datasource_read_array_main(Datasource *source,
 							buffer);
 	  else
 	       return datasource_sndfile_read_array_fp
-		    (source,sampleno,size/source->format.samplebytes,buffer);
+		    (source,sampleno,size/source->format.samplebytes,buffer) * 
+		    source->format.samplebytes;
      case DATASOURCE_REF:
 	  return datasource_read_array_main(source->data.clone,sampleno,size,
 					    buffer,dither_mode,clipcount);
@@ -730,6 +732,8 @@ guint datasource_read_array_fp(Datasource *source, off_t sampleno,
      gchar *p;
      guint x,s;
      
+     g_assert(source->opencount > 0);
+
      g_assert(sampleno <= source->length);
      if (samples > source->length-sampleno) 
 	  samples = (guint)(source->length-sampleno);
