@@ -44,6 +44,7 @@
 #include "help.h"
 #include "ladspadialog.h"
 #include "gettext.h"
+#include "bitmap.h"
 
 #include "button_open.xpm"
 #include "button_save.xpm"
@@ -65,12 +66,16 @@
 #include "button_mixer.xpm"
 #include "button_bounce.xpm"
 #include "icon.xpm"
-#include "vzoom.xpm"
-#include "hzoom.xpm"
-#include "speed.xpm"
+#include "vzoom.xbm"
+#include "hzoom.xbm"
+#include "speed.xbm"
 
 /* #define SHOW_DEBUG_MENU */
 
+#if GTK_MAJOR_VERSION < 2
+#define INV_SPEED
+#endif
+
 ListObject *mainwindow_objects = NULL;
 
 static gboolean window_geometry_stack_inited = FALSE;
@@ -463,11 +468,14 @@ static void do_play(Mainwindow *w, off_t start, off_t end, gboolean loop)
      if (varispeed_reset_flag && 
 	 !(player_playing() && playing_document == w->doc))
 	  speed_reset = TRUE;
-     if (speed_reset) {
-	  document_stop(w->doc,FALSE);
-	  gtk_adjustment_set_value(w->speed_adj,-1.0);
-     }
-     document_play(w->doc, start, end, loop, -w->speed_adj->value);
+     if (speed_reset) document_stop(w->doc,FALSE);
+#ifdef INV_SPEED
+     if (speed_reset) gtk_adjustment_set_value(w->speed_adj,-1.0);
+     document_play(w->doc, start, end, loop, -w->speed_adj->value);     
+#else
+     if (speed_reset) gtk_adjustment_set_value(w->speed_adj,1.0);
+     document_play(w->doc, start, end, loop, w->speed_adj->value);
+#endif
      update_desc(w);
 }
 
@@ -1079,7 +1087,7 @@ static void dump_format(Dataformat *df)
 {
      printf("%d Channels @ %dHz ",df->channels,df->samplerate);
      if (df->type == DATAFORMAT_FLOAT) {
-	  if (df->samplesize > sizeof(float)) {
+	  if (df->samplesize <= sizeof(float)) {
 	       puts("float");
 	  } else
 	       puts("double");
@@ -1274,14 +1282,15 @@ static void edit_playall(GtkMenuItem *menuitem, gpointer user_data)
      do_play(w,0,w->doc->chunk->length,w->loopmode);
 }
 
-static void help_readme(void)
+static void help_readme(GtkMenuItem *menuitem, gpointer user_data)
 {
      GtkAccelGroup* ag;
      GtkWidget *window,*table,*notebook,*frame,*label,*button,*box1,*box2;
      int i;
      GtkWidget *scrolledwindow1, *viewport1, *label2;
 #if GTK_MAJOR_VERSION == 2
-GtkStyle *style;
+     Mainwindow *mw = MAINWINDOW(user_data);
+     PangoFontDescription *pfd;
 #endif
      ag = gtk_accel_group_new();
 
@@ -1328,9 +1337,10 @@ GtkStyle *style;
 #if GTK_MAJOR_VERSION == 2
 if (i==HELP_PAGE_SHORTCUTS)	// Keyboard tab only
 {
-	style = gtk_style_copy (gtk_widget_get_style (label2));
-	style->font_desc = pango_font_description_from_string("Monospace 11");  // Courier also works
-	gtk_widget_set_style (label2, style);
+     pfd = pango_font_description_copy_static(GTK_WIDGET(mw)->style->font_desc);
+     pango_font_description_set_family_static(pfd, "Monospace");
+     gtk_widget_modify_font(label2, pfd);
+     pango_font_description_free(pfd);
 }
 #endif
 	gtk_container_add (GTK_CONTAINER (viewport1), label2);
@@ -2359,9 +2369,14 @@ static void mainwindow_speed_changed(GtkAdjustment *adjustment,
 {
      Mainwindow *w = MAINWINDOW(user_data);
      gchar c[32];
+     gfloat f;
+     f = adjustment->value;
+#ifdef INV_SPEED     
+     f = -f;
+#endif
      if (w->doc == playing_document)
-	  player_set_speed(-adjustment->value);
-     g_snprintf(c,sizeof(c),"%d%%",(int)(-adjustment->value*100.0+0.5));
+	  player_set_speed(f);
+     g_snprintf(c,sizeof(c),"%d%%",(int)(f*100.0+0.5));
      gtk_label_set_text(w->speed_label,c);
 }
 
@@ -2380,11 +2395,43 @@ static void mainwindow_view_double_click(ChunkView *view,
      document_set_selection(wnd->doc,o[1],o[2]);
 }
 
+static gint hzoom_scale_press(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+{
+     Mainwindow *mw = MAINWINDOW(user_data);
+     if (event->button == 3) {
+	  gtk_adjustment_set_value(mw->zoom_adj, 0);
+	  return TRUE;
+     }
+     return FALSE;
+}
+
+static gint vzoom_scale_press(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+{
+     Mainwindow *mw = MAINWINDOW(user_data);
+     if (event->button == 3) {
+	  gtk_adjustment_set_value(mw->vertical_zoom_adj, 0);
+	  return TRUE;
+     }
+     return FALSE;
+}
+
+static gint speed_scale_press(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+{
+     Mainwindow *mw = MAINWINDOW(user_data);
+     if (event->button == 3) {
+#ifdef INV_SPEED
+	  gtk_adjustment_set_value(mw->speed_adj, -1.0);
+#else
+	  gtk_adjustment_set_value(mw->speed_adj, 1.0);
+#endif
+	  return TRUE;
+     }
+     return FALSE;
+}
+
 static void mainwindow_init(Mainwindow *obj)
 {
      GtkWidget *a,*b,*c;
-     GdkPixmap *p;
-     GdkBitmap *mask;
      GtkRequisition req;
      GtkTargetEntry gte;
 
@@ -2416,8 +2463,13 @@ static void mainwindow_init(Mainwindow *obj)
      gtk_signal_connect( GTK_OBJECT(obj->vertical_zoom_adj), "value-changed",
 			 GTK_SIGNAL_FUNC(mainwindow_vertical_zoom_changed),
 			 obj);
+#ifdef INV_SPEED
      obj->speed_adj =
-	  GTK_ADJUSTMENT(gtk_adjustment_new(-1.0,-5.0,0.19,0.01,0.1,0.2));
+	  GTK_ADJUSTMENT(gtk_adjustment_new(-1.0,-2.0,0.20,0.01,0.1,0.2));
+#else
+     obj->speed_adj =
+	  GTK_ADJUSTMENT(gtk_adjustment_new(1.0,0.0,2.2,0.01,0.1,0.2));
+#endif
      gtk_signal_connect(GTK_OBJECT(obj->speed_adj),"value-changed",
 			GTK_SIGNAL_FUNC(mainwindow_speed_changed),
 			obj);
@@ -2465,21 +2517,18 @@ static void mainwindow_init(Mainwindow *obj)
 
      gtk_table_attach(GTK_TABLE(b),c,0,1,0,1,GTK_SHRINK|GTK_FILL,GTK_FILL,0,0);
 
-     p = gdk_pixmap_colormap_create_from_xpm_d
-	  (NULL,gtk_widget_get_colormap(GTK_WIDGET(obj)),&mask,NULL,vzoom_xpm);
-     c = gtk_pixmap_new(p,mask);
+     c = bitmap_new_from_data(vzoom_bits, vzoom_width, vzoom_height);
+     bitmap_set_fg(BITMAP(c),0.8);     
      gtk_table_attach(GTK_TABLE(b),c,1,2,0,1,GTK_FILL,0,0,0);
      obj->vzoom_icon = c;
 
-     p = gdk_pixmap_colormap_create_from_xpm_d
-	  (NULL,gtk_widget_get_colormap(GTK_WIDGET(obj)),&mask,NULL,hzoom_xpm);
-     c = gtk_pixmap_new(p,mask);
+     c = bitmap_new_from_data(hzoom_bits, hzoom_width, hzoom_height);
+     bitmap_set_fg(BITMAP(c),0.8);
      gtk_table_attach(GTK_TABLE(b),c,2,3,0,1,GTK_FILL,0,0,0);
      obj->hzoom_icon = c;
 
-     p = gdk_pixmap_colormap_create_from_xpm_d
-	  (NULL,gtk_widget_get_colormap(GTK_WIDGET(obj)),&mask,NULL,speed_xpm);
-     c = gtk_pixmap_new(p,mask);
+     c = bitmap_new_from_data(speed_bits, speed_width, speed_height);
+     bitmap_set_fg(BITMAP(c),0.8);
      gtk_table_attach(GTK_TABLE(b),c,3,4,0,1,GTK_FILL,0,0,0);
      obj->speed_icon = c;
 
@@ -2488,6 +2537,13 @@ static void mainwindow_init(Mainwindow *obj)
 		      GTK_EXPAND|GTK_FILL|GTK_SHRINK,0,0);
 
      c = gtk_vscale_new ( obj->zoom_adj );
+     /* GTK1 doesn't work well with using the right mouse button press event. 
+      * As a work around, we use the release event instead */
+#if GTK_MAJOR_VERSION > 1
+     gtk_signal_connect(GTK_OBJECT(c),"button_press_event",GTK_SIGNAL_FUNC(hzoom_scale_press),obj);
+#else
+     gtk_signal_connect(GTK_OBJECT(c),"button_release_event",GTK_SIGNAL_FUNC(hzoom_scale_press),obj);
+#endif
      gtk_scale_set_digits(GTK_SCALE(c),3);
      gtk_scale_set_draw_value (GTK_SCALE(c), FALSE);
      gtk_table_attach(GTK_TABLE(b),c,2,3,1,2,GTK_FILL,GTK_EXPAND|GTK_FILL,0,0);
@@ -2495,6 +2551,11 @@ static void mainwindow_init(Mainwindow *obj)
      obj->hzoom_slider = c;
 
      c = gtk_vscale_new ( obj->vertical_zoom_adj );
+#if GTK_MAJOR_VERSION > 1
+     gtk_signal_connect(GTK_OBJECT(c),"button_press_event",GTK_SIGNAL_FUNC(vzoom_scale_press),obj);
+#else
+     gtk_signal_connect(GTK_OBJECT(c),"button_release_event",GTK_SIGNAL_FUNC(vzoom_scale_press),obj);
+#endif
      gtk_scale_set_digits(GTK_SCALE(c),3);
      gtk_scale_set_draw_value (GTK_SCALE(c), FALSE);
      gtk_table_attach(GTK_TABLE(b),c,1,2,1,2,GTK_FILL,GTK_EXPAND|GTK_FILL,0,0);
@@ -2502,9 +2563,17 @@ static void mainwindow_init(Mainwindow *obj)
      obj->vzoom_slider = c;
 
      c = gtk_vscale_new ( obj->speed_adj );
+#if GTK_MAJOR_VERSION > 1
+     gtk_signal_connect(GTK_OBJECT(c),"button_press_event",GTK_SIGNAL_FUNC(speed_scale_press),obj);
+#else
+     gtk_signal_connect(GTK_OBJECT(c),"button_release_event",GTK_SIGNAL_FUNC(speed_scale_press),obj);
+#endif
      gtk_scale_set_digits(GTK_SCALE(c),2);
      gtk_scale_set_draw_value (GTK_SCALE(c), FALSE);
      /* gtk_range_set_update_policy(GTK_RANGE(c),GTK_UPDATE_DELAYED); */
+#ifndef INV_SPEED
+     gtk_range_set_inverted(GTK_RANGE(c),TRUE);
+#endif
      gtk_table_attach(GTK_TABLE(b),c,3,4,1,2,GTK_FILL,GTK_EXPAND|GTK_FILL,0,0);
      obj->need_chunk_items = g_list_append(obj->need_chunk_items,c);
      obj->speed_slider = c;
