@@ -30,6 +30,7 @@
 #include "rateest.h"
 #include "rateconv.h"
 #include "gettext.h"
+#include "mainloop.h"
 
 Dataformat player_fallback_format = { DATAFORMAT_PCM, 44100, 2, 0, 0, TRUE, 
 				      IS_BIGENDIAN };
@@ -39,8 +40,11 @@ gboolean varispeed_smooth_flag = FALSE;
 /* Info about currently playing sound. */
 static ChunkHandle *ch=NULL; /* NULL == stopped */
 static rateconv *varispeed_conv = NULL;
-static gfloat file_speed = 1.0; /* Speed relative to file's sample rate */
-static gfloat true_speed = 1.0; /* Speed relative to playback sample rate */
+/* Note speed is inverse relative to output sample rate */
+/* file_speed is the speed which the user "hears" */
+static gfloat file_speed = 1.0; /* Speed relative to file's sample rate (1.0=Normal speed)*/
+static gfloat true_speed = 1.0; /* Speed relative to playback sample rate (file_speed* file_rate/output_rate) */
+static gfloat file_output_ratio = 1.0; /* file_rate/output_rate */
 static off_t loopstart, loopend, curpos;
 static off_t realpos_offset;
 static gboolean loop, small_loop;
@@ -61,6 +65,9 @@ static gint varispeed_bufsize,varispeed_bufpos;
 static gchar player_buf[4096],small_loop_buf[4096];
 static gint player_bufsize,player_bufpos,small_loop_bufsize;
 
+static player_notify_func notify_func;
+
+static off_t get_realpos_main(off_t frames_played);
 
 static int get_frames(void *buffer, int maxsize)
 {
@@ -123,9 +130,10 @@ static void get_new_data(void)
 /* Check if the sound driver wants more data and send it.
  * Returns FALSE if it had nothing to do. */
 
-gboolean player_work(void)
+static gboolean player_work(void)
 {
      guint32 i;
+     off_t o;
      if (!ch || !output_want_data()) return FALSE;
      if (player_bufpos == player_bufsize) {
 	  /* puts("Hey 1"); */
@@ -135,13 +143,21 @@ gboolean player_work(void)
 	       /* puts("Calling output_play(NULL,0)"); */
 	       i = output_play(NULL,0);
 	       /* puts("output_play done"); */
-	       if (i > 0 || rateest_frames_played()<rateest_frames_written()) 
+	       o = rateest_frames_played();
+	       if (i > 0 || o<rateest_frames_written()) {
+		    if (notify_func != NULL)
+			 notify_func(get_realpos_main(o),TRUE);
+		    /* The sound layer will not call us again so we must
+		     * do it ourselves */
+		    mainloop_defer_once((defer_once_cb)player_work, 50, NULL);
 		    return FALSE;
+	       }
 	       /* puts("Calling output_stop"); */
 	       output_stop(TRUE);
 	       chunk_close(ch);
 	       gtk_object_unref(GTK_OBJECT(ch));
 	       ch=NULL;
+	       if (notify_func != NULL) notify_func(loopstart,FALSE);
 	       return FALSE;
 	  }
      }
@@ -150,6 +166,8 @@ gboolean player_work(void)
      i = output_play(player_buf+player_bufpos,player_bufsize-player_bufpos);
      player_bufpos += i;
      rateest_log_data(i/ch->format.samplebytes);
+     if (i>0 && notify_func!=NULL) 
+	  notify_func(player_get_real_pos(),TRUE);
      return (i>0);
 }
 
@@ -201,6 +219,7 @@ static gboolean player_play_main(Chunk *chk, off_t spos, off_t epos,
      player_stop();
      if (spos == epos) return TRUE;
      true_speed = file_speed;
+     file_output_ratio = 1.0;
      memcpy(&fmt,&(chk->format),sizeof(Dataformat));
      i = output_select_format(&(chk->format),silent,(GVoidFunc)player_work);
      if (i != 0) {	  
@@ -208,6 +227,7 @@ static gboolean player_play_main(Chunk *chk, off_t spos, off_t epos,
 	       if (!output_suggest_format(&(chk->format),&fmt)) {
 		    memcpy(&fmt,&player_fallback_format,sizeof(Dataformat));
 		    fmt.channels = chk->format.channels;
+		    fmt.samplebytes = fmt.samplesize * fmt.channels;
 	       }
 	       
 	       b = !dataformat_samples_equal(&(chk->format),&fmt); 
@@ -225,17 +245,17 @@ static gboolean player_play_main(Chunk *chk, off_t spos, off_t epos,
 
 	       } else if (chk->format.samplerate != fmt.samplerate) {
 
+		    file_output_ratio = ((float)chk->format.samplerate) / ((float)fmt.samplerate);
 		    if (!inifile_get_gboolean("varispeed",TRUE)) {
 			 /* If we don't have varispeed, still play the sound
 			  * with the wrong speed */
 
 			 true_speed = 1.0;/* the only possible w/o varispeed */
-			 file_speed = ((float)fmt.samplerate) / 
-			      ((float)chk->format.samplerate);
+			 file_speed = 1.0 / file_output_ratio;
 		    } else {
-			 true_speed = file_speed * 
-			      ((float)chk->format.samplerate) /
-			      ((float)fmt.samplerate);
+			 /* Resample to get correct playback speed */
+			 file_speed = 1.0;
+			 true_speed = 1.0 * file_output_ratio;
 		    }
 		    /* Select the format with different sample rate */
 		    i = output_select_format(&fmt,FALSE,(GVoidFunc)player_work);
@@ -280,8 +300,11 @@ static gboolean player_play_main(Chunk *chk, off_t spos, off_t epos,
      return FALSE;
 }
 
-gboolean player_play(Chunk *chk, off_t spos, off_t epos, gboolean lp)
+gboolean player_play(Chunk *chk, off_t spos, off_t epos, gboolean lp, 
+		     player_notify_func nf)
 {
+     player_stop();
+     notify_func = nf;
      return player_play_main(chk,spos,epos,lp,TRUE);
 }
 
@@ -347,7 +370,7 @@ void player_change_range(off_t start, off_t end)
 	  rp = player_get_real_pos();
 	  if (rp > curpos) {
 	       /* Fixme: Should handle error return (although unlikely) */
-	       player_play(ch,rp,end,TRUE);
+	       player_play(ch,rp,end,TRUE,notify_func);
 	       loopstart = start;
 	       return;
 	  }
@@ -448,6 +471,7 @@ void player_stop(void)
      b = output_stop(FALSE);
      realpos_atstop = get_realpos_main(b ? rateest_frames_written() : 
 				       rateest_frames_played());
+     if (notify_func) notify_func(realpos_atstop,FALSE);
      gtk_object_unref(GTK_OBJECT(ch));
      ch = NULL;
 }
@@ -484,7 +508,7 @@ void player_set_speed(gfloat s)
      rp = get_realpos_main(pl);
 
      os = true_speed;
-     true_speed *= (s / file_speed);
+     true_speed = s * file_output_ratio;
      file_speed = s;
 
      if (varispeed_smooth_flag) {
